"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "no-multiple-empty-lines";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  rejected: function rejected(line) {
    return "Unexpected empty line at line " + line;
  }
});

exports.messages = messages;

exports["default"] = function () {
  return function (root, result) {
    var lineCount = 0;
    var rootString = root.source.input.css;
    (0, _utils.styleSearch)({ source: rootString, target: ["\n", "\r"], checkComments: true }, function (match) {
      lineCount++;
      if (isNewline(rootString[match.startIndex + 1]) && isNewline(rootString[match.startIndex + 2])) {
        var line = lineCount + 2;
        (0, _utils.report)({
          message: messages.rejected(line),
          node: root,
          line: line,
          result: result,
          ruleName: ruleName
        });
      }
    });
  };
};

function isNewline(char) {
  return char === "\n" || char === "\r";
}