"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _postcss = require("postcss");

var _utils = require("../../utils");

var ruleName = "rule-properties-order";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: function expected(first, second) {
    return "Expected property \"" + first + "\" to come before property \"" + second + "\"";
  }
});

exports.messages = messages;

exports["default"] = function (expectation) {
  return function (root, result) {

    root.eachRule(function (rule) {

      var previousProp = {};
      var isFirstDecl = true;

      rule.eachDecl(function (decl) {

        var prop = {
          name: decl.prop,
          unprefixedName: _postcss.vendor.unprefixed(decl.prop)
        };

        // skip first decl
        if (isFirstDecl) {
          isFirstDecl = false;
          previousProp = prop;
          return;
        }

        // same unprefixed property name
        if (prop.unprefixedName === previousProp.unprefixedName && prop.name >= previousProp.name) {
          previousProp = prop;
          return;
        }

        // different unprefixed property names
        if (prop.unprefixedName !== previousProp.unprefixedName) {

          // alphabetical
          if (expectation === "alphabetical" && prop.unprefixedName >= previousProp.unprefixedName) {
            previousProp = prop;
            return;
          }

          // array of properties
          if (Array.isArray(expectation)) {

            var propIndex = expectation.indexOf(prop.unprefixedName);
            var previousPropIndex = expectation.indexOf(previousProp.unprefixedName);

            // check that two known properties are in order
            if (propIndex !== -1 && previousPropIndex !== -1 && propIndex >= previousPropIndex) {
              previousProp = prop;
              return;
            }

            // skip over unknown properties as any subsequent known properties will flag
            if (propIndex === -1) {
              previousProp = prop;
              return;
            }
          }
        }

        (0, _utils.report)({
          message: messages.expected(prop.name, previousProp.name),
          node: decl,
          result: result,
          ruleName: ruleName
        });

        previousProp = prop;
      });
    });
  };
};